#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsPerson import InsPerson
from alipay.aop.api.domain.InsObject import InsObject
from alipay.aop.api.domain.InsPerson import InsPerson
from alipay.aop.api.domain.InsPerson import InsPerson


class AlipayInsSceneApplicationApplyModel(object):

    def __init__(self):
        self._activity_id = None
        self._applicant = None
        self._bill_title = None
        self._biz_data = None
        self._csu_no = None
        self._effect_start_time = None
        self._ins_objects = None
        self._insureds = None
        self._out_biz_no = None
        self._period = None
        self._premium = None
        self._prod_code = None
        self._recom_flow_no = None
        self._source = None
        self._stake_holders = None
        self._sum_insured = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def applicant(self):
        return self._applicant

    @applicant.setter
    def applicant(self, value):
        if isinstance(value, InsPerson):
            self._applicant = value
        else:
            self._applicant = InsPerson.from_alipay_dict(value)
    @property
    def bill_title(self):
        return self._bill_title

    @bill_title.setter
    def bill_title(self, value):
        self._bill_title = value
    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def csu_no(self):
        return self._csu_no

    @csu_no.setter
    def csu_no(self, value):
        self._csu_no = value
    @property
    def effect_start_time(self):
        return self._effect_start_time

    @effect_start_time.setter
    def effect_start_time(self, value):
        self._effect_start_time = value
    @property
    def ins_objects(self):
        return self._ins_objects

    @ins_objects.setter
    def ins_objects(self, value):
        if isinstance(value, list):
            self._ins_objects = list()
            for i in value:
                if isinstance(i, InsObject):
                    self._ins_objects.append(i)
                else:
                    self._ins_objects.append(InsObject.from_alipay_dict(i))
    @property
    def insureds(self):
        return self._insureds

    @insureds.setter
    def insureds(self, value):
        if isinstance(value, list):
            self._insureds = list()
            for i in value:
                if isinstance(i, InsPerson):
                    self._insureds.append(i)
                else:
                    self._insureds.append(InsPerson.from_alipay_dict(i))
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        self._period = value
    @property
    def premium(self):
        return self._premium

    @premium.setter
    def premium(self, value):
        self._premium = value
    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value
    @property
    def recom_flow_no(self):
        return self._recom_flow_no

    @recom_flow_no.setter
    def recom_flow_no(self, value):
        self._recom_flow_no = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def stake_holders(self):
        return self._stake_holders

    @stake_holders.setter
    def stake_holders(self, value):
        if isinstance(value, list):
            self._stake_holders = list()
            for i in value:
                if isinstance(i, InsPerson):
                    self._stake_holders.append(i)
                else:
                    self._stake_holders.append(InsPerson.from_alipay_dict(i))
    @property
    def sum_insured(self):
        return self._sum_insured

    @sum_insured.setter
    def sum_insured(self, value):
        self._sum_insured = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.applicant:
            if hasattr(self.applicant, 'to_alipay_dict'):
                params['applicant'] = self.applicant.to_alipay_dict()
            else:
                params['applicant'] = self.applicant
        if self.bill_title:
            if hasattr(self.bill_title, 'to_alipay_dict'):
                params['bill_title'] = self.bill_title.to_alipay_dict()
            else:
                params['bill_title'] = self.bill_title
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.csu_no:
            if hasattr(self.csu_no, 'to_alipay_dict'):
                params['csu_no'] = self.csu_no.to_alipay_dict()
            else:
                params['csu_no'] = self.csu_no
        if self.effect_start_time:
            if hasattr(self.effect_start_time, 'to_alipay_dict'):
                params['effect_start_time'] = self.effect_start_time.to_alipay_dict()
            else:
                params['effect_start_time'] = self.effect_start_time
        if self.ins_objects:
            if isinstance(self.ins_objects, list):
                for i in range(0, len(self.ins_objects)):
                    element = self.ins_objects[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ins_objects[i] = element.to_alipay_dict()
            if hasattr(self.ins_objects, 'to_alipay_dict'):
                params['ins_objects'] = self.ins_objects.to_alipay_dict()
            else:
                params['ins_objects'] = self.ins_objects
        if self.insureds:
            if isinstance(self.insureds, list):
                for i in range(0, len(self.insureds)):
                    element = self.insureds[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.insureds[i] = element.to_alipay_dict()
            if hasattr(self.insureds, 'to_alipay_dict'):
                params['insureds'] = self.insureds.to_alipay_dict()
            else:
                params['insureds'] = self.insureds
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        if self.premium:
            if hasattr(self.premium, 'to_alipay_dict'):
                params['premium'] = self.premium.to_alipay_dict()
            else:
                params['premium'] = self.premium
        if self.prod_code:
            if hasattr(self.prod_code, 'to_alipay_dict'):
                params['prod_code'] = self.prod_code.to_alipay_dict()
            else:
                params['prod_code'] = self.prod_code
        if self.recom_flow_no:
            if hasattr(self.recom_flow_no, 'to_alipay_dict'):
                params['recom_flow_no'] = self.recom_flow_no.to_alipay_dict()
            else:
                params['recom_flow_no'] = self.recom_flow_no
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.stake_holders:
            if isinstance(self.stake_holders, list):
                for i in range(0, len(self.stake_holders)):
                    element = self.stake_holders[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.stake_holders[i] = element.to_alipay_dict()
            if hasattr(self.stake_holders, 'to_alipay_dict'):
                params['stake_holders'] = self.stake_holders.to_alipay_dict()
            else:
                params['stake_holders'] = self.stake_holders
        if self.sum_insured:
            if hasattr(self.sum_insured, 'to_alipay_dict'):
                params['sum_insured'] = self.sum_insured.to_alipay_dict()
            else:
                params['sum_insured'] = self.sum_insured
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneApplicationApplyModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'applicant' in d:
            o.applicant = d['applicant']
        if 'bill_title' in d:
            o.bill_title = d['bill_title']
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'csu_no' in d:
            o.csu_no = d['csu_no']
        if 'effect_start_time' in d:
            o.effect_start_time = d['effect_start_time']
        if 'ins_objects' in d:
            o.ins_objects = d['ins_objects']
        if 'insureds' in d:
            o.insureds = d['insureds']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'period' in d:
            o.period = d['period']
        if 'premium' in d:
            o.premium = d['premium']
        if 'prod_code' in d:
            o.prod_code = d['prod_code']
        if 'recom_flow_no' in d:
            o.recom_flow_no = d['recom_flow_no']
        if 'source' in d:
            o.source = d['source']
        if 'stake_holders' in d:
            o.stake_holders = d['stake_holders']
        if 'sum_insured' in d:
            o.sum_insured = d['sum_insured']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ContactModel import ContactModel


class AlipayOpenAgentCreateModel(object):

    def __init__(self):
        self._account = None
        self._contact_info = None
        self._order_ticket = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def contact_info(self):
        return self._contact_info

    @contact_info.setter
    def contact_info(self, value):
        if isinstance(value, ContactModel):
            self._contact_info = value
        else:
            self._contact_info = ContactModel.from_alipay_dict(value)
    @property
    def order_ticket(self):
        return self._order_ticket

    @order_ticket.setter
    def order_ticket(self, value):
        self._order_ticket = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.contact_info:
            if hasattr(self.contact_info, 'to_alipay_dict'):
                params['contact_info'] = self.contact_info.to_alipay_dict()
            else:
                params['contact_info'] = self.contact_info
        if self.order_ticket:
            if hasattr(self.order_ticket, 'to_alipay_dict'):
                params['order_ticket'] = self.order_ticket.to_alipay_dict()
            else:
                params['order_ticket'] = self.order_ticket
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAgentCreateModel()
        if 'account' in d:
            o.account = d['account']
        if 'contact_info' in d:
            o.contact_info = d['contact_info']
        if 'order_ticket' in d:
            o.order_ticket = d['order_ticket']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceIotMdeviceprodWhitelistQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotMdeviceprodWhitelistQueryResponse, self).__init__()
        self._app_project_id = None
        self._app_white_list_status = None
        self._effective_time = None
        self._expire_time = None
        self._ext_info = None
        self._gmt_create = None
        self._gmt_modified = None
        self._group_type = None
        self._group_value = None
        self._remark = None
        self._user_identify_type = None
        self._user_identify_value = None

    @property
    def app_project_id(self):
        return self._app_project_id

    @app_project_id.setter
    def app_project_id(self, value):
        self._app_project_id = value
    @property
    def app_white_list_status(self):
        return self._app_white_list_status

    @app_white_list_status.setter
    def app_white_list_status(self, value):
        self._app_white_list_status = value
    @property
    def effective_time(self):
        return self._effective_time

    @effective_time.setter
    def effective_time(self, value):
        self._effective_time = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def group_type(self):
        return self._group_type

    @group_type.setter
    def group_type(self, value):
        self._group_type = value
    @property
    def group_value(self):
        return self._group_value

    @group_value.setter
    def group_value(self, value):
        self._group_value = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def user_identify_type(self):
        return self._user_identify_type

    @user_identify_type.setter
    def user_identify_type(self, value):
        self._user_identify_type = value
    @property
    def user_identify_value(self):
        return self._user_identify_value

    @user_identify_value.setter
    def user_identify_value(self, value):
        self._user_identify_value = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotMdeviceprodWhitelistQueryResponse, self).parse_response_content(response_content)
        if 'app_project_id' in response:
            self.app_project_id = response['app_project_id']
        if 'app_white_list_status' in response:
            self.app_white_list_status = response['app_white_list_status']
        if 'effective_time' in response:
            self.effective_time = response['effective_time']
        if 'expire_time' in response:
            self.expire_time = response['expire_time']
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'gmt_modified' in response:
            self.gmt_modified = response['gmt_modified']
        if 'group_type' in response:
            self.group_type = response['group_type']
        if 'group_value' in response:
            self.group_value = response['group_value']
        if 'remark' in response:
            self.remark = response['remark']
        if 'user_identify_type' in response:
            self.user_identify_type = response['user_identify_type']
        if 'user_identify_value' in response:
            self.user_identify_value = response['user_identify_value']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ResourceUserDataVO(object):

    def __init__(self):
        self._profile_type = None
        self._profile_value = None
        self._report_date = None
        self._user_cnt = None
        self._user_ratio = None

    @property
    def profile_type(self):
        return self._profile_type

    @profile_type.setter
    def profile_type(self, value):
        self._profile_type = value
    @property
    def profile_value(self):
        return self._profile_value

    @profile_value.setter
    def profile_value(self, value):
        self._profile_value = value
    @property
    def report_date(self):
        return self._report_date

    @report_date.setter
    def report_date(self, value):
        self._report_date = value
    @property
    def user_cnt(self):
        return self._user_cnt

    @user_cnt.setter
    def user_cnt(self, value):
        self._user_cnt = value
    @property
    def user_ratio(self):
        return self._user_ratio

    @user_ratio.setter
    def user_ratio(self, value):
        self._user_ratio = value


    def to_alipay_dict(self):
        params = dict()
        if self.profile_type:
            if hasattr(self.profile_type, 'to_alipay_dict'):
                params['profile_type'] = self.profile_type.to_alipay_dict()
            else:
                params['profile_type'] = self.profile_type
        if self.profile_value:
            if hasattr(self.profile_value, 'to_alipay_dict'):
                params['profile_value'] = self.profile_value.to_alipay_dict()
            else:
                params['profile_value'] = self.profile_value
        if self.report_date:
            if hasattr(self.report_date, 'to_alipay_dict'):
                params['report_date'] = self.report_date.to_alipay_dict()
            else:
                params['report_date'] = self.report_date
        if self.user_cnt:
            if hasattr(self.user_cnt, 'to_alipay_dict'):
                params['user_cnt'] = self.user_cnt.to_alipay_dict()
            else:
                params['user_cnt'] = self.user_cnt
        if self.user_ratio:
            if hasattr(self.user_ratio, 'to_alipay_dict'):
                params['user_ratio'] = self.user_ratio.to_alipay_dict()
            else:
                params['user_ratio'] = self.user_ratio
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ResourceUserDataVO()
        if 'profile_type' in d:
            o.profile_type = d['profile_type']
        if 'profile_value' in d:
            o.profile_value = d['profile_value']
        if 'report_date' in d:
            o.report_date = d['report_date']
        if 'user_cnt' in d:
            o.user_cnt = d['user_cnt']
        if 'user_ratio' in d:
            o.user_ratio = d['user_ratio']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FengdieSpaceDomains import FengdieSpaceDomains


class FengdieSpaceDetailModel(object):

    def __init__(self):
        self._domains = None
        self._gmt_create = None
        self._space_id = None
        self._title = None

    @property
    def domains(self):
        return self._domains

    @domains.setter
    def domains(self, value):
        if isinstance(value, list):
            self._domains = list()
            for i in value:
                if isinstance(i, FengdieSpaceDomains):
                    self._domains.append(i)
                else:
                    self._domains.append(FengdieSpaceDomains.from_alipay_dict(i))
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def space_id(self):
        return self._space_id

    @space_id.setter
    def space_id(self, value):
        self._space_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.domains:
            if isinstance(self.domains, list):
                for i in range(0, len(self.domains)):
                    element = self.domains[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.domains[i] = element.to_alipay_dict()
            if hasattr(self.domains, 'to_alipay_dict'):
                params['domains'] = self.domains.to_alipay_dict()
            else:
                params['domains'] = self.domains
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.space_id:
            if hasattr(self.space_id, 'to_alipay_dict'):
                params['space_id'] = self.space_id.to_alipay_dict()
            else:
                params['space_id'] = self.space_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FengdieSpaceDetailModel()
        if 'domains' in d:
            o.domains = d['domains']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'space_id' in d:
            o.space_id = d['space_id']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CrowdConstraintInfo import CrowdConstraintInfo
from alipay.aop.api.domain.IntelligentPromoEffect import IntelligentPromoEffect
from alipay.aop.api.domain.InteligentBudgetInfo import InteligentBudgetInfo
from alipay.aop.api.domain.InteligentConstraintInfo import InteligentConstraintInfo
from alipay.aop.api.domain.InteligentPromoTool import InteligentPromoTool
from alipay.aop.api.domain.InteligentPublishChannel import InteligentPublishChannel


class InteligentGeneralMerchantPromo(object):

    def __init__(self):
        self._camp_id = None
        self._crowd_constraint = None
        self._desc = None
        self._ext_info = None
        self._forecast_effect = None
        self._inteligent_budget = None
        self._inteligent_constraint = None
        self._inteligent_promo_tools = None
        self._inteligent_publish_channels = None
        self._merchant_promo_type = None
        self._name = None
        self._template_id = None

    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def crowd_constraint(self):
        return self._crowd_constraint

    @crowd_constraint.setter
    def crowd_constraint(self, value):
        if isinstance(value, CrowdConstraintInfo):
            self._crowd_constraint = value
        else:
            self._crowd_constraint = CrowdConstraintInfo.from_alipay_dict(value)
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def forecast_effect(self):
        return self._forecast_effect

    @forecast_effect.setter
    def forecast_effect(self, value):
        if isinstance(value, IntelligentPromoEffect):
            self._forecast_effect = value
        else:
            self._forecast_effect = IntelligentPromoEffect.from_alipay_dict(value)
    @property
    def inteligent_budget(self):
        return self._inteligent_budget

    @inteligent_budget.setter
    def inteligent_budget(self, value):
        if isinstance(value, InteligentBudgetInfo):
            self._inteligent_budget = value
        else:
            self._inteligent_budget = InteligentBudgetInfo.from_alipay_dict(value)
    @property
    def inteligent_constraint(self):
        return self._inteligent_constraint

    @inteligent_constraint.setter
    def inteligent_constraint(self, value):
        if isinstance(value, InteligentConstraintInfo):
            self._inteligent_constraint = value
        else:
            self._inteligent_constraint = InteligentConstraintInfo.from_alipay_dict(value)
    @property
    def inteligent_promo_tools(self):
        return self._inteligent_promo_tools

    @inteligent_promo_tools.setter
    def inteligent_promo_tools(self, value):
        if isinstance(value, list):
            self._inteligent_promo_tools = list()
            for i in value:
                if isinstance(i, InteligentPromoTool):
                    self._inteligent_promo_tools.append(i)
                else:
                    self._inteligent_promo_tools.append(InteligentPromoTool.from_alipay_dict(i))
    @property
    def inteligent_publish_channels(self):
        return self._inteligent_publish_channels

    @inteligent_publish_channels.setter
    def inteligent_publish_channels(self, value):
        if isinstance(value, list):
            self._inteligent_publish_channels = list()
            for i in value:
                if isinstance(i, InteligentPublishChannel):
                    self._inteligent_publish_channels.append(i)
                else:
                    self._inteligent_publish_channels.append(InteligentPublishChannel.from_alipay_dict(i))
    @property
    def merchant_promo_type(self):
        return self._merchant_promo_type

    @merchant_promo_type.setter
    def merchant_promo_type(self, value):
        self._merchant_promo_type = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.camp_id:
            if hasattr(self.camp_id, 'to_alipay_dict'):
                params['camp_id'] = self.camp_id.to_alipay_dict()
            else:
                params['camp_id'] = self.camp_id
        if self.crowd_constraint:
            if hasattr(self.crowd_constraint, 'to_alipay_dict'):
                params['crowd_constraint'] = self.crowd_constraint.to_alipay_dict()
            else:
                params['crowd_constraint'] = self.crowd_constraint
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.forecast_effect:
            if hasattr(self.forecast_effect, 'to_alipay_dict'):
                params['forecast_effect'] = self.forecast_effect.to_alipay_dict()
            else:
                params['forecast_effect'] = self.forecast_effect
        if self.inteligent_budget:
            if hasattr(self.inteligent_budget, 'to_alipay_dict'):
                params['inteligent_budget'] = self.inteligent_budget.to_alipay_dict()
            else:
                params['inteligent_budget'] = self.inteligent_budget
        if self.inteligent_constraint:
            if hasattr(self.inteligent_constraint, 'to_alipay_dict'):
                params['inteligent_constraint'] = self.inteligent_constraint.to_alipay_dict()
            else:
                params['inteligent_constraint'] = self.inteligent_constraint
        if self.inteligent_promo_tools:
            if isinstance(self.inteligent_promo_tools, list):
                for i in range(0, len(self.inteligent_promo_tools)):
                    element = self.inteligent_promo_tools[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.inteligent_promo_tools[i] = element.to_alipay_dict()
            if hasattr(self.inteligent_promo_tools, 'to_alipay_dict'):
                params['inteligent_promo_tools'] = self.inteligent_promo_tools.to_alipay_dict()
            else:
                params['inteligent_promo_tools'] = self.inteligent_promo_tools
        if self.inteligent_publish_channels:
            if isinstance(self.inteligent_publish_channels, list):
                for i in range(0, len(self.inteligent_publish_channels)):
                    element = self.inteligent_publish_channels[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.inteligent_publish_channels[i] = element.to_alipay_dict()
            if hasattr(self.inteligent_publish_channels, 'to_alipay_dict'):
                params['inteligent_publish_channels'] = self.inteligent_publish_channels.to_alipay_dict()
            else:
                params['inteligent_publish_channels'] = self.inteligent_publish_channels
        if self.merchant_promo_type:
            if hasattr(self.merchant_promo_type, 'to_alipay_dict'):
                params['merchant_promo_type'] = self.merchant_promo_type.to_alipay_dict()
            else:
                params['merchant_promo_type'] = self.merchant_promo_type
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InteligentGeneralMerchantPromo()
        if 'camp_id' in d:
            o.camp_id = d['camp_id']
        if 'crowd_constraint' in d:
            o.crowd_constraint = d['crowd_constraint']
        if 'desc' in d:
            o.desc = d['desc']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'forecast_effect' in d:
            o.forecast_effect = d['forecast_effect']
        if 'inteligent_budget' in d:
            o.inteligent_budget = d['inteligent_budget']
        if 'inteligent_constraint' in d:
            o.inteligent_constraint = d['inteligent_constraint']
        if 'inteligent_promo_tools' in d:
            o.inteligent_promo_tools = d['inteligent_promo_tools']
        if 'inteligent_publish_channels' in d:
            o.inteligent_publish_channels = d['inteligent_publish_channels']
        if 'merchant_promo_type' in d:
            o.merchant_promo_type = d['merchant_promo_type']
        if 'name' in d:
            o.name = d['name']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AntdataassetsOdpsColumn import AntdataassetsOdpsColumn


class AlipayDataDataserviceAntdataassetsUploadjobCreateModel(object):

    def __init__(self):
        self._guid = None
        self._odps_columns = None

    @property
    def guid(self):
        return self._guid

    @guid.setter
    def guid(self, value):
        self._guid = value
    @property
    def odps_columns(self):
        return self._odps_columns

    @odps_columns.setter
    def odps_columns(self, value):
        if isinstance(value, list):
            self._odps_columns = list()
            for i in value:
                if isinstance(i, AntdataassetsOdpsColumn):
                    self._odps_columns.append(i)
                else:
                    self._odps_columns.append(AntdataassetsOdpsColumn.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.guid:
            if hasattr(self.guid, 'to_alipay_dict'):
                params['guid'] = self.guid.to_alipay_dict()
            else:
                params['guid'] = self.guid
        if self.odps_columns:
            if isinstance(self.odps_columns, list):
                for i in range(0, len(self.odps_columns)):
                    element = self.odps_columns[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.odps_columns[i] = element.to_alipay_dict()
            if hasattr(self.odps_columns, 'to_alipay_dict'):
                params['odps_columns'] = self.odps_columns.to_alipay_dict()
            else:
                params['odps_columns'] = self.odps_columns
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceAntdataassetsUploadjobCreateModel()
        if 'guid' in d:
            o.guid = d['guid']
        if 'odps_columns' in d:
            o.odps_columns = d['odps_columns']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherTermInfo import VoucherTermInfo


class VoucherModifyInfo(object):

    def __init__(self):
        self._suitable_shops = None
        self._voucher_desc = None
        self._voucher_id = None
        self._voucher_name = None
        self._voucher_terms = None

    @property
    def suitable_shops(self):
        return self._suitable_shops

    @suitable_shops.setter
    def suitable_shops(self, value):
        if isinstance(value, list):
            self._suitable_shops = list()
            for i in value:
                self._suitable_shops.append(i)
    @property
    def voucher_desc(self):
        return self._voucher_desc

    @voucher_desc.setter
    def voucher_desc(self, value):
        self._voucher_desc = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value
    @property
    def voucher_terms(self):
        return self._voucher_terms

    @voucher_terms.setter
    def voucher_terms(self, value):
        if isinstance(value, list):
            self._voucher_terms = list()
            for i in value:
                if isinstance(i, VoucherTermInfo):
                    self._voucher_terms.append(i)
                else:
                    self._voucher_terms.append(VoucherTermInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.suitable_shops:
            if isinstance(self.suitable_shops, list):
                for i in range(0, len(self.suitable_shops)):
                    element = self.suitable_shops[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.suitable_shops[i] = element.to_alipay_dict()
            if hasattr(self.suitable_shops, 'to_alipay_dict'):
                params['suitable_shops'] = self.suitable_shops.to_alipay_dict()
            else:
                params['suitable_shops'] = self.suitable_shops
        if self.voucher_desc:
            if hasattr(self.voucher_desc, 'to_alipay_dict'):
                params['voucher_desc'] = self.voucher_desc.to_alipay_dict()
            else:
                params['voucher_desc'] = self.voucher_desc
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        if self.voucher_terms:
            if isinstance(self.voucher_terms, list):
                for i in range(0, len(self.voucher_terms)):
                    element = self.voucher_terms[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.voucher_terms[i] = element.to_alipay_dict()
            if hasattr(self.voucher_terms, 'to_alipay_dict'):
                params['voucher_terms'] = self.voucher_terms.to_alipay_dict()
            else:
                params['voucher_terms'] = self.voucher_terms
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherModifyInfo()
        if 'suitable_shops' in d:
            o.suitable_shops = d['suitable_shops']
        if 'voucher_desc' in d:
            o.voucher_desc = d['voucher_desc']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        if 'voucher_terms' in d:
            o.voucher_terms = d['voucher_terms']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VehicleToken(object):

    def __init__(self):
        self._expires_in_timestamp = None
        self._refresh_expires_in_timestamp = None
        self._vehicle_access_token = None
        self._vehicle_refresh_token = None

    @property
    def expires_in_timestamp(self):
        return self._expires_in_timestamp

    @expires_in_timestamp.setter
    def expires_in_timestamp(self, value):
        self._expires_in_timestamp = value
    @property
    def refresh_expires_in_timestamp(self):
        return self._refresh_expires_in_timestamp

    @refresh_expires_in_timestamp.setter
    def refresh_expires_in_timestamp(self, value):
        self._refresh_expires_in_timestamp = value
    @property
    def vehicle_access_token(self):
        return self._vehicle_access_token

    @vehicle_access_token.setter
    def vehicle_access_token(self, value):
        self._vehicle_access_token = value
    @property
    def vehicle_refresh_token(self):
        return self._vehicle_refresh_token

    @vehicle_refresh_token.setter
    def vehicle_refresh_token(self, value):
        self._vehicle_refresh_token = value


    def to_alipay_dict(self):
        params = dict()
        if self.expires_in_timestamp:
            if hasattr(self.expires_in_timestamp, 'to_alipay_dict'):
                params['expires_in_timestamp'] = self.expires_in_timestamp.to_alipay_dict()
            else:
                params['expires_in_timestamp'] = self.expires_in_timestamp
        if self.refresh_expires_in_timestamp:
            if hasattr(self.refresh_expires_in_timestamp, 'to_alipay_dict'):
                params['refresh_expires_in_timestamp'] = self.refresh_expires_in_timestamp.to_alipay_dict()
            else:
                params['refresh_expires_in_timestamp'] = self.refresh_expires_in_timestamp
        if self.vehicle_access_token:
            if hasattr(self.vehicle_access_token, 'to_alipay_dict'):
                params['vehicle_access_token'] = self.vehicle_access_token.to_alipay_dict()
            else:
                params['vehicle_access_token'] = self.vehicle_access_token
        if self.vehicle_refresh_token:
            if hasattr(self.vehicle_refresh_token, 'to_alipay_dict'):
                params['vehicle_refresh_token'] = self.vehicle_refresh_token.to_alipay_dict()
            else:
                params['vehicle_refresh_token'] = self.vehicle_refresh_token
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VehicleToken()
        if 'expires_in_timestamp' in d:
            o.expires_in_timestamp = d['expires_in_timestamp']
        if 'refresh_expires_in_timestamp' in d:
            o.refresh_expires_in_timestamp = d['refresh_expires_in_timestamp']
        if 'vehicle_access_token' in d:
            o.vehicle_access_token = d['vehicle_access_token']
        if 'vehicle_refresh_token' in d:
            o.vehicle_refresh_token = d['vehicle_refresh_token']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AccountFreeze import AccountFreeze


class AlipayUserAccountFreezeGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAccountFreezeGetResponse, self).__init__()
        self._freeze_items = None
        self._total_results = None

    @property
    def freeze_items(self):
        return self._freeze_items

    @freeze_items.setter
    def freeze_items(self, value):
        if isinstance(value, list):
            self._freeze_items = list()
            for i in value:
                if isinstance(i, AccountFreeze):
                    self._freeze_items.append(i)
                else:
                    self._freeze_items.append(AccountFreeze.from_alipay_dict(i))
    @property
    def total_results(self):
        return self._total_results

    @total_results.setter
    def total_results(self, value):
        self._total_results = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAccountFreezeGetResponse, self).parse_response_content(response_content)
        if 'freeze_items' in response:
            self.freeze_items = response['freeze_items']
        if 'total_results' in response:
            self.total_results = response['total_results']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.FileItem import FileItem
from alipay.aop.api.constant.ParamConstants import *

from alipay.aop.api.domain.ZhimaMerchantContractCommonCancelModel import ZhimaMerchantContractCommonCancelModel



class ZhimaMerchantContractCommonCancelRequest(object):

    def __init__(self, biz_model=None):
        self._biz_model = biz_model
        self._biz_content = None
        self._version = "1.0"
        self._terminal_type = None
        self._terminal_info = None
        self._prod_code = None
        self._notify_url = None
        self._return_url = None
        self._udf_params = None
        self._need_encrypt = False

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        self._biz_model = value

    @property
    def biz_content(self):
        return self._biz_content

    @biz_content.setter
    def biz_content(self, value):
        if isinstance(value, ZhimaMerchantContractCommonCancelModel):
            self._biz_content = value
        else:
            self._biz_content = ZhimaMerchantContractCommonCancelModel.from_alipay_dict(value)


    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value

    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value

    @property
    def terminal_info(self):
        return self._terminal_info

    @terminal_info.setter
    def terminal_info(self, value):
        self._terminal_info = value

    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value

    @property
    def notify_url(self):
        return self._notify_url

    @notify_url.setter
    def notify_url(self, value):
        self._notify_url = value

    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value

    @property
    def udf_params(self):
        return self._udf_params

    @udf_params.setter
    def udf_params(self, value):
        if not isinstance(value, dict):
            return
        self._udf_params = value

    @property
    def need_encrypt(self):
        return self._need_encrypt

    @need_encrypt.setter
    def need_encrypt(self, value):
        self._need_encrypt = value

    def add_other_text_param(self, key, value):
        if not self.udf_params:
            self.udf_params = dict()
        self.udf_params[key] = value

    def get_params(self):
        params = dict()
        params[P_METHOD] = 'zhima.merchant.contract.common.cancel'
        params[P_VERSION] = self.version
        if self.biz_model:
            params[P_BIZ_CONTENT] = json.dumps(obj=self.biz_model.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
        if self.biz_content:
            if hasattr(self.biz_content, 'to_alipay_dict'):
                params['biz_content'] = json.dumps(obj=self.biz_content.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['biz_content'] = self.biz_content
        if self.terminal_type:
            params['terminal_type'] = self.terminal_type
        if self.terminal_info:
            params['terminal_info'] = self.terminal_info
        if self.prod_code:
            params['prod_code'] = self.prod_code
        if self.notify_url:
            params['notify_url'] = self.notify_url
        if self.return_url:
            params['return_url'] = self.return_url
        if self.udf_params:
            params.update(self.udf_params)
        return params

    def get_multipart_params(self):
        multipart_params = dict()
        return multipart_params



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GoodsDetail import GoodsDetail


class AlipayPayAppMarketingConsultModel(object):

    def __init__(self):
        self._biz_scene = None
        self._blind_mobile = None
        self._confused_mobile_list = None
        self._device_id = None
        self._device_type = None
        self._encrypted_mobile = None
        self._goods_detail = None
        self._mobile = None
        self._need_query_anti_rank = None
        self._need_query_marketing_rank = None
        self._need_return_tag = None
        self._out_trade_no = None
        self._product_code = None
        self._promo_params = None
        self._seller_id = None
        self._total_amount = None
        self._undiscountable_amount = None
        self._user_id = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def blind_mobile(self):
        return self._blind_mobile

    @blind_mobile.setter
    def blind_mobile(self, value):
        self._blind_mobile = value
    @property
    def confused_mobile_list(self):
        return self._confused_mobile_list

    @confused_mobile_list.setter
    def confused_mobile_list(self, value):
        if isinstance(value, list):
            self._confused_mobile_list = list()
            for i in value:
                self._confused_mobile_list.append(i)
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def device_type(self):
        return self._device_type

    @device_type.setter
    def device_type(self, value):
        self._device_type = value
    @property
    def encrypted_mobile(self):
        return self._encrypted_mobile

    @encrypted_mobile.setter
    def encrypted_mobile(self, value):
        self._encrypted_mobile = value
    @property
    def goods_detail(self):
        return self._goods_detail

    @goods_detail.setter
    def goods_detail(self, value):
        if isinstance(value, list):
            self._goods_detail = list()
            for i in value:
                if isinstance(i, GoodsDetail):
                    self._goods_detail.append(i)
                else:
                    self._goods_detail.append(GoodsDetail.from_alipay_dict(i))
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def need_query_anti_rank(self):
        return self._need_query_anti_rank

    @need_query_anti_rank.setter
    def need_query_anti_rank(self, value):
        self._need_query_anti_rank = value
    @property
    def need_query_marketing_rank(self):
        return self._need_query_marketing_rank

    @need_query_marketing_rank.setter
    def need_query_marketing_rank(self, value):
        self._need_query_marketing_rank = value
    @property
    def need_return_tag(self):
        return self._need_return_tag

    @need_return_tag.setter
    def need_return_tag(self, value):
        self._need_return_tag = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def promo_params(self):
        return self._promo_params

    @promo_params.setter
    def promo_params(self, value):
        self._promo_params = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def undiscountable_amount(self):
        return self._undiscountable_amount

    @undiscountable_amount.setter
    def undiscountable_amount(self, value):
        self._undiscountable_amount = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.blind_mobile:
            if hasattr(self.blind_mobile, 'to_alipay_dict'):
                params['blind_mobile'] = self.blind_mobile.to_alipay_dict()
            else:
                params['blind_mobile'] = self.blind_mobile
        if self.confused_mobile_list:
            if isinstance(self.confused_mobile_list, list):
                for i in range(0, len(self.confused_mobile_list)):
                    element = self.confused_mobile_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.confused_mobile_list[i] = element.to_alipay_dict()
            if hasattr(self.confused_mobile_list, 'to_alipay_dict'):
                params['confused_mobile_list'] = self.confused_mobile_list.to_alipay_dict()
            else:
                params['confused_mobile_list'] = self.confused_mobile_list
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.device_type:
            if hasattr(self.device_type, 'to_alipay_dict'):
                params['device_type'] = self.device_type.to_alipay_dict()
            else:
                params['device_type'] = self.device_type
        if self.encrypted_mobile:
            if hasattr(self.encrypted_mobile, 'to_alipay_dict'):
                params['encrypted_mobile'] = self.encrypted_mobile.to_alipay_dict()
            else:
                params['encrypted_mobile'] = self.encrypted_mobile
        if self.goods_detail:
            if isinstance(self.goods_detail, list):
                for i in range(0, len(self.goods_detail)):
                    element = self.goods_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_detail[i] = element.to_alipay_dict()
            if hasattr(self.goods_detail, 'to_alipay_dict'):
                params['goods_detail'] = self.goods_detail.to_alipay_dict()
            else:
                params['goods_detail'] = self.goods_detail
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.need_query_anti_rank:
            if hasattr(self.need_query_anti_rank, 'to_alipay_dict'):
                params['need_query_anti_rank'] = self.need_query_anti_rank.to_alipay_dict()
            else:
                params['need_query_anti_rank'] = self.need_query_anti_rank
        if self.need_query_marketing_rank:
            if hasattr(self.need_query_marketing_rank, 'to_alipay_dict'):
                params['need_query_marketing_rank'] = self.need_query_marketing_rank.to_alipay_dict()
            else:
                params['need_query_marketing_rank'] = self.need_query_marketing_rank
        if self.need_return_tag:
            if hasattr(self.need_return_tag, 'to_alipay_dict'):
                params['need_return_tag'] = self.need_return_tag.to_alipay_dict()
            else:
                params['need_return_tag'] = self.need_return_tag
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.promo_params:
            if hasattr(self.promo_params, 'to_alipay_dict'):
                params['promo_params'] = self.promo_params.to_alipay_dict()
            else:
                params['promo_params'] = self.promo_params
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.undiscountable_amount:
            if hasattr(self.undiscountable_amount, 'to_alipay_dict'):
                params['undiscountable_amount'] = self.undiscountable_amount.to_alipay_dict()
            else:
                params['undiscountable_amount'] = self.undiscountable_amount
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPayAppMarketingConsultModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'blind_mobile' in d:
            o.blind_mobile = d['blind_mobile']
        if 'confused_mobile_list' in d:
            o.confused_mobile_list = d['confused_mobile_list']
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'device_type' in d:
            o.device_type = d['device_type']
        if 'encrypted_mobile' in d:
            o.encrypted_mobile = d['encrypted_mobile']
        if 'goods_detail' in d:
            o.goods_detail = d['goods_detail']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'need_query_anti_rank' in d:
            o.need_query_anti_rank = d['need_query_anti_rank']
        if 'need_query_marketing_rank' in d:
            o.need_query_marketing_rank = d['need_query_marketing_rank']
        if 'need_return_tag' in d:
            o.need_return_tag = d['need_return_tag']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'promo_params' in d:
            o.promo_params = d['promo_params']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'undiscountable_amount' in d:
            o.undiscountable_amount = d['undiscountable_amount']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherUserExternalTradeInfo(object):

    def __init__(self):
        self._amount = None
        self._consume_date = None
        self._consume_shop_id = None
        self._external_trade_no = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def consume_date(self):
        return self._consume_date

    @consume_date.setter
    def consume_date(self, value):
        self._consume_date = value
    @property
    def consume_shop_id(self):
        return self._consume_shop_id

    @consume_shop_id.setter
    def consume_shop_id(self, value):
        self._consume_shop_id = value
    @property
    def external_trade_no(self):
        return self._external_trade_no

    @external_trade_no.setter
    def external_trade_no(self, value):
        self._external_trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.consume_date:
            if hasattr(self.consume_date, 'to_alipay_dict'):
                params['consume_date'] = self.consume_date.to_alipay_dict()
            else:
                params['consume_date'] = self.consume_date
        if self.consume_shop_id:
            if hasattr(self.consume_shop_id, 'to_alipay_dict'):
                params['consume_shop_id'] = self.consume_shop_id.to_alipay_dict()
            else:
                params['consume_shop_id'] = self.consume_shop_id
        if self.external_trade_no:
            if hasattr(self.external_trade_no, 'to_alipay_dict'):
                params['external_trade_no'] = self.external_trade_no.to_alipay_dict()
            else:
                params['external_trade_no'] = self.external_trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherUserExternalTradeInfo()
        if 'amount' in d:
            o.amount = d['amount']
        if 'consume_date' in d:
            o.consume_date = d['consume_date']
        if 'consume_shop_id' in d:
            o.consume_shop_id = d['consume_shop_id']
        if 'external_trade_no' in d:
            o.external_trade_no = d['external_trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingCampaignMemberRelationBindModel(object):

    def __init__(self):
        self._activate_time = None
        self._balance = None
        self._birth = None
        self._cell = None
        self._end_time = None
        self._gender = None
        self._level = None
        self._member_template_id = None
        self._out_member_no = None
        self._point = None
        self._request_id = None
        self._start_time = None
        self._user_id = None
        self._user_name = None

    @property
    def activate_time(self):
        return self._activate_time

    @activate_time.setter
    def activate_time(self, value):
        self._activate_time = value
    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def birth(self):
        return self._birth

    @birth.setter
    def birth(self, value):
        self._birth = value
    @property
    def cell(self):
        return self._cell

    @cell.setter
    def cell(self, value):
        self._cell = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def level(self):
        return self._level

    @level.setter
    def level(self, value):
        self._level = value
    @property
    def member_template_id(self):
        return self._member_template_id

    @member_template_id.setter
    def member_template_id(self, value):
        self._member_template_id = value
    @property
    def out_member_no(self):
        return self._out_member_no

    @out_member_no.setter
    def out_member_no(self, value):
        self._out_member_no = value
    @property
    def point(self):
        return self._point

    @point.setter
    def point(self, value):
        self._point = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.activate_time:
            if hasattr(self.activate_time, 'to_alipay_dict'):
                params['activate_time'] = self.activate_time.to_alipay_dict()
            else:
                params['activate_time'] = self.activate_time
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.birth:
            if hasattr(self.birth, 'to_alipay_dict'):
                params['birth'] = self.birth.to_alipay_dict()
            else:
                params['birth'] = self.birth
        if self.cell:
            if hasattr(self.cell, 'to_alipay_dict'):
                params['cell'] = self.cell.to_alipay_dict()
            else:
                params['cell'] = self.cell
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.level:
            if hasattr(self.level, 'to_alipay_dict'):
                params['level'] = self.level.to_alipay_dict()
            else:
                params['level'] = self.level
        if self.member_template_id:
            if hasattr(self.member_template_id, 'to_alipay_dict'):
                params['member_template_id'] = self.member_template_id.to_alipay_dict()
            else:
                params['member_template_id'] = self.member_template_id
        if self.out_member_no:
            if hasattr(self.out_member_no, 'to_alipay_dict'):
                params['out_member_no'] = self.out_member_no.to_alipay_dict()
            else:
                params['out_member_no'] = self.out_member_no
        if self.point:
            if hasattr(self.point, 'to_alipay_dict'):
                params['point'] = self.point.to_alipay_dict()
            else:
                params['point'] = self.point
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignMemberRelationBindModel()
        if 'activate_time' in d:
            o.activate_time = d['activate_time']
        if 'balance' in d:
            o.balance = d['balance']
        if 'birth' in d:
            o.birth = d['birth']
        if 'cell' in d:
            o.cell = d['cell']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'gender' in d:
            o.gender = d['gender']
        if 'level' in d:
            o.level = d['level']
        if 'member_template_id' in d:
            o.member_template_id = d['member_template_id']
        if 'out_member_no' in d:
            o.out_member_no = d['out_member_no']
        if 'point' in d:
            o.point = d['point']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CardPriceRequestItem import CardPriceRequestItem
from alipay.aop.api.domain.MakePriceExtParams import MakePriceExtParams


class AlipayDataAiserviceBikepriceGetModel(object):

    def __init__(self):
        self._ad_source = None
        self._card_type_version = None
        self._channel = None
        self._city_code = None
        self._constraints = None
        self._from = None
        self._make_price_ext_params = None
        self._plat_form = None
        self._rank = None
        self._scene_code = None
        self._service_name = None
        self._system_code = None
        self._trace_id = None
        self._user_attribute = None
        self._user_id = None

    @property
    def ad_source(self):
        return self._ad_source

    @ad_source.setter
    def ad_source(self, value):
        self._ad_source = value
    @property
    def card_type_version(self):
        return self._card_type_version

    @card_type_version.setter
    def card_type_version(self, value):
        self._card_type_version = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def constraints(self):
        return self._constraints

    @constraints.setter
    def constraints(self, value):
        if isinstance(value, list):
            self._constraints = list()
            for i in value:
                if isinstance(i, CardPriceRequestItem):
                    self._constraints.append(i)
                else:
                    self._constraints.append(CardPriceRequestItem.from_alipay_dict(i))
    @property
    def from(self):
        return self._from

    @from.setter
    def from(self, value):
        self._from = value
    @property
    def make_price_ext_params(self):
        return self._make_price_ext_params

    @make_price_ext_params.setter
    def make_price_ext_params(self, value):
        if isinstance(value, MakePriceExtParams):
            self._make_price_ext_params = value
        else:
            self._make_price_ext_params = MakePriceExtParams.from_alipay_dict(value)
    @property
    def plat_form(self):
        return self._plat_form

    @plat_form.setter
    def plat_form(self, value):
        self._plat_form = value
    @property
    def rank(self):
        return self._rank

    @rank.setter
    def rank(self, value):
        self._rank = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value
    @property
    def system_code(self):
        return self._system_code

    @system_code.setter
    def system_code(self, value):
        self._system_code = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value
    @property
    def user_attribute(self):
        return self._user_attribute

    @user_attribute.setter
    def user_attribute(self, value):
        self._user_attribute = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ad_source:
            if hasattr(self.ad_source, 'to_alipay_dict'):
                params['ad_source'] = self.ad_source.to_alipay_dict()
            else:
                params['ad_source'] = self.ad_source
        if self.card_type_version:
            if hasattr(self.card_type_version, 'to_alipay_dict'):
                params['card_type_version'] = self.card_type_version.to_alipay_dict()
            else:
                params['card_type_version'] = self.card_type_version
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.constraints:
            if isinstance(self.constraints, list):
                for i in range(0, len(self.constraints)):
                    element = self.constraints[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.constraints[i] = element.to_alipay_dict()
            if hasattr(self.constraints, 'to_alipay_dict'):
                params['constraints'] = self.constraints.to_alipay_dict()
            else:
                params['constraints'] = self.constraints
        if self.from:
            if hasattr(self.from, 'to_alipay_dict'):
                params['from'] = self.from.to_alipay_dict()
            else:
                params['from'] = self.from
        if self.make_price_ext_params:
            if hasattr(self.make_price_ext_params, 'to_alipay_dict'):
                params['make_price_ext_params'] = self.make_price_ext_params.to_alipay_dict()
            else:
                params['make_price_ext_params'] = self.make_price_ext_params
        if self.plat_form:
            if hasattr(self.plat_form, 'to_alipay_dict'):
                params['plat_form'] = self.plat_form.to_alipay_dict()
            else:
                params['plat_form'] = self.plat_form
        if self.rank:
            if hasattr(self.rank, 'to_alipay_dict'):
                params['rank'] = self.rank.to_alipay_dict()
            else:
                params['rank'] = self.rank
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        if self.system_code:
            if hasattr(self.system_code, 'to_alipay_dict'):
                params['system_code'] = self.system_code.to_alipay_dict()
            else:
                params['system_code'] = self.system_code
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        if self.user_attribute:
            if hasattr(self.user_attribute, 'to_alipay_dict'):
                params['user_attribute'] = self.user_attribute.to_alipay_dict()
            else:
                params['user_attribute'] = self.user_attribute
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataAiserviceBikepriceGetModel()
        if 'ad_source' in d:
            o.ad_source = d['ad_source']
        if 'card_type_version' in d:
            o.card_type_version = d['card_type_version']
        if 'channel' in d:
            o.channel = d['channel']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'constraints' in d:
            o.constraints = d['constraints']
        if 'from' in d:
            o.from = d['from']
        if 'make_price_ext_params' in d:
            o.make_price_ext_params = d['make_price_ext_params']
        if 'plat_form' in d:
            o.plat_form = d['plat_form']
        if 'rank' in d:
            o.rank = d['rank']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'service_name' in d:
            o.service_name = d['service_name']
        if 'system_code' in d:
            o.system_code = d['system_code']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        if 'user_attribute' in d:
            o.user_attribute = d['user_attribute']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TaskVoucherBasicInfo(object):

    def __init__(self):
        self._logo = None
        self._reduction_amount = None
        self._threshold_amount = None
        self._total_used_count = None
        self._used_count = None
        self._voucher_name = None
        self._voucher_template_no = None

    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def reduction_amount(self):
        return self._reduction_amount

    @reduction_amount.setter
    def reduction_amount(self, value):
        self._reduction_amount = value
    @property
    def threshold_amount(self):
        return self._threshold_amount

    @threshold_amount.setter
    def threshold_amount(self, value):
        self._threshold_amount = value
    @property
    def total_used_count(self):
        return self._total_used_count

    @total_used_count.setter
    def total_used_count(self, value):
        self._total_used_count = value
    @property
    def used_count(self):
        return self._used_count

    @used_count.setter
    def used_count(self, value):
        self._used_count = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value
    @property
    def voucher_template_no(self):
        return self._voucher_template_no

    @voucher_template_no.setter
    def voucher_template_no(self, value):
        self._voucher_template_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.reduction_amount:
            if hasattr(self.reduction_amount, 'to_alipay_dict'):
                params['reduction_amount'] = self.reduction_amount.to_alipay_dict()
            else:
                params['reduction_amount'] = self.reduction_amount
        if self.threshold_amount:
            if hasattr(self.threshold_amount, 'to_alipay_dict'):
                params['threshold_amount'] = self.threshold_amount.to_alipay_dict()
            else:
                params['threshold_amount'] = self.threshold_amount
        if self.total_used_count:
            if hasattr(self.total_used_count, 'to_alipay_dict'):
                params['total_used_count'] = self.total_used_count.to_alipay_dict()
            else:
                params['total_used_count'] = self.total_used_count
        if self.used_count:
            if hasattr(self.used_count, 'to_alipay_dict'):
                params['used_count'] = self.used_count.to_alipay_dict()
            else:
                params['used_count'] = self.used_count
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        if self.voucher_template_no:
            if hasattr(self.voucher_template_no, 'to_alipay_dict'):
                params['voucher_template_no'] = self.voucher_template_no.to_alipay_dict()
            else:
                params['voucher_template_no'] = self.voucher_template_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TaskVoucherBasicInfo()
        if 'logo' in d:
            o.logo = d['logo']
        if 'reduction_amount' in d:
            o.reduction_amount = d['reduction_amount']
        if 'threshold_amount' in d:
            o.threshold_amount = d['threshold_amount']
        if 'total_used_count' in d:
            o.total_used_count = d['total_used_count']
        if 'used_count' in d:
            o.used_count = d['used_count']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        if 'voucher_template_no' in d:
            o.voucher_template_no = d['voucher_template_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaMerchantContractCommonCancelModel(object):

    def __init__(self):
        self._contract_no = None
        self._sign_principal_id = None

    @property
    def contract_no(self):
        return self._contract_no

    @contract_no.setter
    def contract_no(self, value):
        self._contract_no = value
    @property
    def sign_principal_id(self):
        return self._sign_principal_id

    @sign_principal_id.setter
    def sign_principal_id(self, value):
        self._sign_principal_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.contract_no:
            if hasattr(self.contract_no, 'to_alipay_dict'):
                params['contract_no'] = self.contract_no.to_alipay_dict()
            else:
                params['contract_no'] = self.contract_no
        if self.sign_principal_id:
            if hasattr(self.sign_principal_id, 'to_alipay_dict'):
                params['sign_principal_id'] = self.sign_principal_id.to_alipay_dict()
            else:
                params['sign_principal_id'] = self.sign_principal_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaMerchantContractCommonCancelModel()
        if 'contract_no' in d:
            o.contract_no = d['contract_no']
        if 'sign_principal_id' in d:
            o.sign_principal_id = d['sign_principal_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExtCardInfo import ExtCardInfo


class AlipayFundAccountQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundAccountQueryResponse, self).__init__()
        self._available_amount = None
        self._ext_card_info = None
        self._freeze_amount = None

    @property
    def available_amount(self):
        return self._available_amount

    @available_amount.setter
    def available_amount(self, value):
        self._available_amount = value
    @property
    def ext_card_info(self):
        return self._ext_card_info

    @ext_card_info.setter
    def ext_card_info(self, value):
        if isinstance(value, ExtCardInfo):
            self._ext_card_info = value
        else:
            self._ext_card_info = ExtCardInfo.from_alipay_dict(value)
    @property
    def freeze_amount(self):
        return self._freeze_amount

    @freeze_amount.setter
    def freeze_amount(self, value):
        self._freeze_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundAccountQueryResponse, self).parse_response_content(response_content)
        if 'available_amount' in response:
            self.available_amount = response['available_amount']
        if 'ext_card_info' in response:
            self.ext_card_info = response['ext_card_info']
        if 'freeze_amount' in response:
            self.freeze_amount = response['freeze_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InsDataDsbEstimateResultDetail import InsDataDsbEstimateResultDetail


class AlipayInsDataDsbEstimateQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsDataDsbEstimateQueryResponse, self).__init__()
        self._confidence = None
        self._estimate_detail_list = None
        self._estimate_no = None
        self._frame_no = None
        self._license_no = None
        self._repair_corp_properties = None
        self._total_damage_amount = None
        self._total_remain_value = None

    @property
    def confidence(self):
        return self._confidence

    @confidence.setter
    def confidence(self, value):
        self._confidence = value
    @property
    def estimate_detail_list(self):
        return self._estimate_detail_list

    @estimate_detail_list.setter
    def estimate_detail_list(self, value):
        if isinstance(value, list):
            self._estimate_detail_list = list()
            for i in value:
                if isinstance(i, InsDataDsbEstimateResultDetail):
                    self._estimate_detail_list.append(i)
                else:
                    self._estimate_detail_list.append(InsDataDsbEstimateResultDetail.from_alipay_dict(i))
    @property
    def estimate_no(self):
        return self._estimate_no

    @estimate_no.setter
    def estimate_no(self, value):
        self._estimate_no = value
    @property
    def frame_no(self):
        return self._frame_no

    @frame_no.setter
    def frame_no(self, value):
        self._frame_no = value
    @property
    def license_no(self):
        return self._license_no

    @license_no.setter
    def license_no(self, value):
        self._license_no = value
    @property
    def repair_corp_properties(self):
        return self._repair_corp_properties

    @repair_corp_properties.setter
    def repair_corp_properties(self, value):
        self._repair_corp_properties = value
    @property
    def total_damage_amount(self):
        return self._total_damage_amount

    @total_damage_amount.setter
    def total_damage_amount(self, value):
        self._total_damage_amount = value
    @property
    def total_remain_value(self):
        return self._total_remain_value

    @total_remain_value.setter
    def total_remain_value(self, value):
        self._total_remain_value = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsDataDsbEstimateQueryResponse, self).parse_response_content(response_content)
        if 'confidence' in response:
            self.confidence = response['confidence']
        if 'estimate_detail_list' in response:
            self.estimate_detail_list = response['estimate_detail_list']
        if 'estimate_no' in response:
            self.estimate_no = response['estimate_no']
        if 'frame_no' in response:
            self.frame_no = response['frame_no']
        if 'license_no' in response:
            self.license_no = response['license_no']
        if 'repair_corp_properties' in response:
            self.repair_corp_properties = response['repair_corp_properties']
        if 'total_damage_amount' in response:
            self.total_damage_amount = response['total_damage_amount']
        if 'total_remain_value' in response:
            self.total_remain_value = response['total_remain_value']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportTaxiDriverqrcodetradeBatchqueryModel(object):

    def __init__(self):
        self._begin_time = None
        self._driver_user_id = None
        self._end_time = None

    @property
    def begin_time(self):
        return self._begin_time

    @begin_time.setter
    def begin_time(self, value):
        self._begin_time = value
    @property
    def driver_user_id(self):
        return self._driver_user_id

    @driver_user_id.setter
    def driver_user_id(self, value):
        self._driver_user_id = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.begin_time:
            if hasattr(self.begin_time, 'to_alipay_dict'):
                params['begin_time'] = self.begin_time.to_alipay_dict()
            else:
                params['begin_time'] = self.begin_time
        if self.driver_user_id:
            if hasattr(self.driver_user_id, 'to_alipay_dict'):
                params['driver_user_id'] = self.driver_user_id.to_alipay_dict()
            else:
                params['driver_user_id'] = self.driver_user_id
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportTaxiDriverqrcodetradeBatchqueryModel()
        if 'begin_time' in d:
            o.begin_time = d['begin_time']
        if 'driver_user_id' in d:
            o.driver_user_id = d['driver_user_id']
        if 'end_time' in d:
            o.end_time = d['end_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityProdFingerprintDeleteModel(object):

    def __init__(self):
        self._ifaa_version = None
        self._sec_data = None
        self._token = None

    @property
    def ifaa_version(self):
        return self._ifaa_version

    @ifaa_version.setter
    def ifaa_version(self, value):
        self._ifaa_version = value
    @property
    def sec_data(self):
        return self._sec_data

    @sec_data.setter
    def sec_data(self, value):
        self._sec_data = value
    @property
    def token(self):
        return self._token

    @token.setter
    def token(self, value):
        self._token = value


    def to_alipay_dict(self):
        params = dict()
        if self.ifaa_version:
            if hasattr(self.ifaa_version, 'to_alipay_dict'):
                params['ifaa_version'] = self.ifaa_version.to_alipay_dict()
            else:
                params['ifaa_version'] = self.ifaa_version
        if self.sec_data:
            if hasattr(self.sec_data, 'to_alipay_dict'):
                params['sec_data'] = self.sec_data.to_alipay_dict()
            else:
                params['sec_data'] = self.sec_data
        if self.token:
            if hasattr(self.token, 'to_alipay_dict'):
                params['token'] = self.token.to_alipay_dict()
            else:
                params['token'] = self.token
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityProdFingerprintDeleteModel()
        if 'ifaa_version' in d:
            o.ifaa_version = d['ifaa_version']
        if 'sec_data' in d:
            o.sec_data = d['sec_data']
        if 'token' in d:
            o.token = d['token']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAuthTokenAppModel(object):

    def __init__(self):
        self._code = None
        self._grant_type = None
        self._refresh_token = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def grant_type(self):
        return self._grant_type

    @grant_type.setter
    def grant_type(self, value):
        self._grant_type = value
    @property
    def refresh_token(self):
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, value):
        self._refresh_token = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.grant_type:
            if hasattr(self.grant_type, 'to_alipay_dict'):
                params['grant_type'] = self.grant_type.to_alipay_dict()
            else:
                params['grant_type'] = self.grant_type
        if self.refresh_token:
            if hasattr(self.refresh_token, 'to_alipay_dict'):
                params['refresh_token'] = self.refresh_token.to_alipay_dict()
            else:
                params['refresh_token'] = self.refresh_token
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAuthTokenAppModel()
        if 'code' in d:
            o.code = d['code']
        if 'grant_type' in d:
            o.grant_type = d['grant_type']
        if 'refresh_token' in d:
            o.refresh_token = d['refresh_token']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeZmgoBizoptCloseResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeZmgoBizoptCloseResponse, self).__init__()
        self._biz_opt_no = None
        self._out_request_no = None
        self._partner_id = None
        self._user_id = None

    @property
    def biz_opt_no(self):
        return self._biz_opt_no

    @biz_opt_no.setter
    def biz_opt_no(self, value):
        self._biz_opt_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeZmgoBizoptCloseResponse, self).parse_response_content(response_content)
        if 'biz_opt_no' in response:
            self.biz_opt_no = response['biz_opt_no']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'partner_id' in response:
            self.partner_id = response['partner_id']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ScheduleConfigItem(object):

    def __init__(self):
        self._config_name = None
        self._date = None
        self._id = None

    @property
    def config_name(self):
        return self._config_name

    @config_name.setter
    def config_name(self, value):
        self._config_name = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value


    def to_alipay_dict(self):
        params = dict()
        if self.config_name:
            if hasattr(self.config_name, 'to_alipay_dict'):
                params['config_name'] = self.config_name.to_alipay_dict()
            else:
                params['config_name'] = self.config_name
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ScheduleConfigItem()
        if 'config_name' in d:
            o.config_name = d['config_name']
        if 'date' in d:
            o.date = d['date']
        if 'id' in d:
            o.id = d['id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.VoucherItem import VoucherItem


class AlipayMarketingCampaignSelfVoucherQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignSelfVoucherQueryResponse, self).__init__()
        self._voucher_item = None

    @property
    def voucher_item(self):
        return self._voucher_item

    @voucher_item.setter
    def voucher_item(self, value):
        if isinstance(value, VoucherItem):
            self._voucher_item = value
        else:
            self._voucher_item = VoucherItem.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignSelfVoucherQueryResponse, self).parse_response_content(response_content)
        if 'voucher_item' in response:
            self.voucher_item = response['voucher_item']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CreativeRefuseExtendInfo(object):

    def __init__(self):
        self._image_url_list = None

    @property
    def image_url_list(self):
        return self._image_url_list

    @image_url_list.setter
    def image_url_list(self, value):
        if isinstance(value, list):
            self._image_url_list = list()
            for i in value:
                self._image_url_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.image_url_list:
            if isinstance(self.image_url_list, list):
                for i in range(0, len(self.image_url_list)):
                    element = self.image_url_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.image_url_list[i] = element.to_alipay_dict()
            if hasattr(self.image_url_list, 'to_alipay_dict'):
                params['image_url_list'] = self.image_url_list.to_alipay_dict()
            else:
                params['image_url_list'] = self.image_url_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CreativeRefuseExtendInfo()
        if 'image_url_list' in d:
            o.image_url_list = d['image_url_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiAuthOrderUnfreezeModel(object):

    def __init__(self):
        self._agreement_no = None
        self._alipay_user_id = None
        self._need_terminated = None
        self._order_title = None
        self._out_request_no = None
        self._seller_id = None
        self._unfreeze_amount = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def need_terminated(self):
        return self._need_terminated

    @need_terminated.setter
    def need_terminated(self, value):
        self._need_terminated = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def unfreeze_amount(self):
        return self._unfreeze_amount

    @unfreeze_amount.setter
    def unfreeze_amount(self, value):
        self._unfreeze_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.need_terminated:
            if hasattr(self.need_terminated, 'to_alipay_dict'):
                params['need_terminated'] = self.need_terminated.to_alipay_dict()
            else:
                params['need_terminated'] = self.need_terminated
        if self.order_title:
            if hasattr(self.order_title, 'to_alipay_dict'):
                params['order_title'] = self.order_title.to_alipay_dict()
            else:
                params['order_title'] = self.order_title
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.unfreeze_amount:
            if hasattr(self.unfreeze_amount, 'to_alipay_dict'):
                params['unfreeze_amount'] = self.unfreeze_amount.to_alipay_dict()
            else:
                params['unfreeze_amount'] = self.unfreeze_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiAuthOrderUnfreezeModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'need_terminated' in d:
            o.need_terminated = d['need_terminated']
        if 'order_title' in d:
            o.order_title = d['order_title']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'unfreeze_amount' in d:
            o.unfreeze_amount = d['unfreeze_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VirtualItemOrderExtInfo import VirtualItemOrderExtInfo


class AlipayCommerceOperationTimescardOrderCreateModel(object):

    def __init__(self):
        self._extend_info = None
        self._isv_partner_id = None
        self._item_id = None
        self._out_biz_no = None
        self._partner_id = None
        self._scene_code = None
        self._user_id = None

    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        if isinstance(value, VirtualItemOrderExtInfo):
            self._extend_info = value
        else:
            self._extend_info = VirtualItemOrderExtInfo.from_alipay_dict(value)
    @property
    def isv_partner_id(self):
        return self._isv_partner_id

    @isv_partner_id.setter
    def isv_partner_id(self, value):
        self._isv_partner_id = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.isv_partner_id:
            if hasattr(self.isv_partner_id, 'to_alipay_dict'):
                params['isv_partner_id'] = self.isv_partner_id.to_alipay_dict()
            else:
                params['isv_partner_id'] = self.isv_partner_id
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationTimescardOrderCreateModel()
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'isv_partner_id' in d:
            o.isv_partner_id = d['isv_partner_id']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayGongyiAddressTest(object):

    def __init__(self):
        self._city = None
        self._contury = None
        self._street = None

    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def contury(self):
        return self._contury

    @contury.setter
    def contury(self, value):
        self._contury = value
    @property
    def street(self):
        return self._street

    @street.setter
    def street(self, value):
        self._street = value


    def to_alipay_dict(self):
        params = dict()
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.contury:
            if hasattr(self.contury, 'to_alipay_dict'):
                params['contury'] = self.contury.to_alipay_dict()
            else:
                params['contury'] = self.contury
        if self.street:
            if hasattr(self.street, 'to_alipay_dict'):
                params['street'] = self.street.to_alipay_dict()
            else:
                params['street'] = self.street
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayGongyiAddressTest()
        if 'city' in d:
            o.city = d['city']
        if 'contury' in d:
            o.contury = d['contury']
        if 'street' in d:
            o.street = d['street']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradePayConsultModel(object):

    def __init__(self):
        self._agreement_no = None
        self._apply_amount = None
        self._biz_scene = None
        self._buyer_id = None
        self._consult_phase = None
        self._extend_params = None
        self._product_code = None
        self._request_no = None
        self._subject = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def apply_amount(self):
        return self._apply_amount

    @apply_amount.setter
    def apply_amount(self, value):
        self._apply_amount = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def consult_phase(self):
        return self._consult_phase

    @consult_phase.setter
    def consult_phase(self, value):
        self._consult_phase = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def request_no(self):
        return self._request_no

    @request_no.setter
    def request_no(self, value):
        self._request_no = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.apply_amount:
            if hasattr(self.apply_amount, 'to_alipay_dict'):
                params['apply_amount'] = self.apply_amount.to_alipay_dict()
            else:
                params['apply_amount'] = self.apply_amount
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.consult_phase:
            if hasattr(self.consult_phase, 'to_alipay_dict'):
                params['consult_phase'] = self.consult_phase.to_alipay_dict()
            else:
                params['consult_phase'] = self.consult_phase
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.request_no:
            if hasattr(self.request_no, 'to_alipay_dict'):
                params['request_no'] = self.request_no.to_alipay_dict()
            else:
                params['request_no'] = self.request_no
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradePayConsultModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'apply_amount' in d:
            o.apply_amount = d['apply_amount']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'consult_phase' in d:
            o.consult_phase = d['consult_phase']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'request_no' in d:
            o.request_no = d['request_no']
        if 'subject' in d:
            o.subject = d['subject']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CityShopModel(object):

    def __init__(self):
        self._city_id = None
        self._city_name = None
        self._district_id = None
        self._district_name = None
        self._pos_shop = None
        self._province_id = None
        self._province_name = None
        self._shop_id = None
        self._shop_name = None
        self._shop_status = None

    @property
    def city_id(self):
        return self._city_id

    @city_id.setter
    def city_id(self, value):
        self._city_id = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def district_id(self):
        return self._district_id

    @district_id.setter
    def district_id(self, value):
        self._district_id = value
    @property
    def district_name(self):
        return self._district_name

    @district_name.setter
    def district_name(self, value):
        self._district_name = value
    @property
    def pos_shop(self):
        return self._pos_shop

    @pos_shop.setter
    def pos_shop(self, value):
        self._pos_shop = value
    @property
    def province_id(self):
        return self._province_id

    @province_id.setter
    def province_id(self, value):
        self._province_id = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_status(self):
        return self._shop_status

    @shop_status.setter
    def shop_status(self, value):
        self._shop_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_id:
            if hasattr(self.city_id, 'to_alipay_dict'):
                params['city_id'] = self.city_id.to_alipay_dict()
            else:
                params['city_id'] = self.city_id
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.district_id:
            if hasattr(self.district_id, 'to_alipay_dict'):
                params['district_id'] = self.district_id.to_alipay_dict()
            else:
                params['district_id'] = self.district_id
        if self.district_name:
            if hasattr(self.district_name, 'to_alipay_dict'):
                params['district_name'] = self.district_name.to_alipay_dict()
            else:
                params['district_name'] = self.district_name
        if self.pos_shop:
            if hasattr(self.pos_shop, 'to_alipay_dict'):
                params['pos_shop'] = self.pos_shop.to_alipay_dict()
            else:
                params['pos_shop'] = self.pos_shop
        if self.province_id:
            if hasattr(self.province_id, 'to_alipay_dict'):
                params['province_id'] = self.province_id.to_alipay_dict()
            else:
                params['province_id'] = self.province_id
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_status:
            if hasattr(self.shop_status, 'to_alipay_dict'):
                params['shop_status'] = self.shop_status.to_alipay_dict()
            else:
                params['shop_status'] = self.shop_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CityShopModel()
        if 'city_id' in d:
            o.city_id = d['city_id']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'district_id' in d:
            o.district_id = d['district_id']
        if 'district_name' in d:
            o.district_name = d['district_name']
        if 'pos_shop' in d:
            o.pos_shop = d['pos_shop']
        if 'province_id' in d:
            o.province_id = d['province_id']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_status' in d:
            o.shop_status = d['shop_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MemberCardUserInfo(object):

    def __init__(self):
        self._birthday = None
        self._gender = None
        self._mobile = None
        self._name = None
        self._open_time = None
        self._user_id = None

    @property
    def birthday(self):
        return self._birthday

    @birthday.setter
    def birthday(self, value):
        self._birthday = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def open_time(self):
        return self._open_time

    @open_time.setter
    def open_time(self, value):
        self._open_time = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.birthday:
            if hasattr(self.birthday, 'to_alipay_dict'):
                params['birthday'] = self.birthday.to_alipay_dict()
            else:
                params['birthday'] = self.birthday
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.open_time:
            if hasattr(self.open_time, 'to_alipay_dict'):
                params['open_time'] = self.open_time.to_alipay_dict()
            else:
                params['open_time'] = self.open_time
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MemberCardUserInfo()
        if 'birthday' in d:
            o.birthday = d['birthday']
        if 'gender' in d:
            o.gender = d['gender']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        if 'open_time' in d:
            o.open_time = d['open_time']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusinessItem(object):

    def __init__(self):
        self._business_appid = None
        self._business_payee_id = None
        self._business_pid = None
        self._business_type = None

    @property
    def business_appid(self):
        return self._business_appid

    @business_appid.setter
    def business_appid(self, value):
        self._business_appid = value
    @property
    def business_payee_id(self):
        return self._business_payee_id

    @business_payee_id.setter
    def business_payee_id(self, value):
        self._business_payee_id = value
    @property
    def business_pid(self):
        return self._business_pid

    @business_pid.setter
    def business_pid(self, value):
        self._business_pid = value
    @property
    def business_type(self):
        return self._business_type

    @business_type.setter
    def business_type(self, value):
        self._business_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_appid:
            if hasattr(self.business_appid, 'to_alipay_dict'):
                params['business_appid'] = self.business_appid.to_alipay_dict()
            else:
                params['business_appid'] = self.business_appid
        if self.business_payee_id:
            if hasattr(self.business_payee_id, 'to_alipay_dict'):
                params['business_payee_id'] = self.business_payee_id.to_alipay_dict()
            else:
                params['business_payee_id'] = self.business_payee_id
        if self.business_pid:
            if hasattr(self.business_pid, 'to_alipay_dict'):
                params['business_pid'] = self.business_pid.to_alipay_dict()
            else:
                params['business_pid'] = self.business_pid
        if self.business_type:
            if hasattr(self.business_type, 'to_alipay_dict'):
                params['business_type'] = self.business_type.to_alipay_dict()
            else:
                params['business_type'] = self.business_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessItem()
        if 'business_appid' in d:
            o.business_appid = d['business_appid']
        if 'business_payee_id' in d:
            o.business_payee_id = d['business_payee_id']
        if 'business_pid' in d:
            o.business_pid = d['business_pid']
        if 'business_type' in d:
            o.business_type = d['business_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class SsdataDataserviceMetainfoSyncResponse(AlipayResponse):

    def __init__(self):
        super(SsdataDataserviceMetainfoSyncResponse, self).__init__()
        self._is_sync_success = None
        self._sync_result = None

    @property
    def is_sync_success(self):
        return self._is_sync_success

    @is_sync_success.setter
    def is_sync_success(self, value):
        self._is_sync_success = value
    @property
    def sync_result(self):
        return self._sync_result

    @sync_result.setter
    def sync_result(self, value):
        self._sync_result = value

    def parse_response_content(self, response_content):
        response = super(SsdataDataserviceMetainfoSyncResponse, self).parse_response_content(response_content)
        if 'is_sync_success' in response:
            self.is_sync_success = response['is_sync_success']
        if 'sync_result' in response:
            self.sync_result = response['sync_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OverseasTravelRate import OverseasTravelRate


class AlipayOverseasTravelExchangerateBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTravelExchangerateBatchqueryResponse, self).__init__()
        self._rate_desc = None
        self._rate_source = None
        self._rates = None

    @property
    def rate_desc(self):
        return self._rate_desc

    @rate_desc.setter
    def rate_desc(self, value):
        self._rate_desc = value
    @property
    def rate_source(self):
        return self._rate_source

    @rate_source.setter
    def rate_source(self, value):
        self._rate_source = value
    @property
    def rates(self):
        return self._rates

    @rates.setter
    def rates(self, value):
        if isinstance(value, list):
            self._rates = list()
            for i in value:
                if isinstance(i, OverseasTravelRate):
                    self._rates.append(i)
                else:
                    self._rates.append(OverseasTravelRate.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTravelExchangerateBatchqueryResponse, self).parse_response_content(response_content)
        if 'rate_desc' in response:
            self.rate_desc = response['rate_desc']
        if 'rate_source' in response:
            self.rate_source = response['rate_source']
        if 'rates' in response:
            self.rates = response['rates']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SquareDanceTaskInfo(object):

    def __init__(self):
        self._application_id = None
        self._biz_type = None
        self._button_action_url = None
        self._button_text = None
        self._ext_info = None
        self._flow_id = None
        self._img_url = None
        self._status = None
        self._sub_title = None
        self._task_id = None
        self._title = None
        self._votes = None

    @property
    def application_id(self):
        return self._application_id

    @application_id.setter
    def application_id(self, value):
        self._application_id = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def button_action_url(self):
        return self._button_action_url

    @button_action_url.setter
    def button_action_url(self, value):
        self._button_action_url = value
    @property
    def button_text(self):
        return self._button_text

    @button_text.setter
    def button_text(self, value):
        self._button_text = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def flow_id(self):
        return self._flow_id

    @flow_id.setter
    def flow_id(self, value):
        self._flow_id = value
    @property
    def img_url(self):
        return self._img_url

    @img_url.setter
    def img_url(self, value):
        self._img_url = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_title(self):
        return self._sub_title

    @sub_title.setter
    def sub_title(self, value):
        self._sub_title = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def votes(self):
        return self._votes

    @votes.setter
    def votes(self, value):
        self._votes = value


    def to_alipay_dict(self):
        params = dict()
        if self.application_id:
            if hasattr(self.application_id, 'to_alipay_dict'):
                params['application_id'] = self.application_id.to_alipay_dict()
            else:
                params['application_id'] = self.application_id
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.button_action_url:
            if hasattr(self.button_action_url, 'to_alipay_dict'):
                params['button_action_url'] = self.button_action_url.to_alipay_dict()
            else:
                params['button_action_url'] = self.button_action_url
        if self.button_text:
            if hasattr(self.button_text, 'to_alipay_dict'):
                params['button_text'] = self.button_text.to_alipay_dict()
            else:
                params['button_text'] = self.button_text
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.flow_id:
            if hasattr(self.flow_id, 'to_alipay_dict'):
                params['flow_id'] = self.flow_id.to_alipay_dict()
            else:
                params['flow_id'] = self.flow_id
        if self.img_url:
            if hasattr(self.img_url, 'to_alipay_dict'):
                params['img_url'] = self.img_url.to_alipay_dict()
            else:
                params['img_url'] = self.img_url
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sub_title:
            if hasattr(self.sub_title, 'to_alipay_dict'):
                params['sub_title'] = self.sub_title.to_alipay_dict()
            else:
                params['sub_title'] = self.sub_title
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.votes:
            if hasattr(self.votes, 'to_alipay_dict'):
                params['votes'] = self.votes.to_alipay_dict()
            else:
                params['votes'] = self.votes
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SquareDanceTaskInfo()
        if 'application_id' in d:
            o.application_id = d['application_id']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'button_action_url' in d:
            o.button_action_url = d['button_action_url']
        if 'button_text' in d:
            o.button_text = d['button_text']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'flow_id' in d:
            o.flow_id = d['flow_id']
        if 'img_url' in d:
            o.img_url = d['img_url']
        if 'status' in d:
            o.status = d['status']
        if 'sub_title' in d:
            o.sub_title = d['sub_title']
        if 'task_id' in d:
            o.task_id = d['task_id']
        if 'title' in d:
            o.title = d['title']
        if 'votes' in d:
            o.votes = d['votes']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CloudbusRoute import CloudbusRoute


class AlipayDataAiserviceCloudbusPredictbuslineSubmitModel(object):

    def __init__(self):
        self._app_version = None
        self._city_code = None
        self._partner_id = None
        self._route_version = None
        self._routes = None
        self._title = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def route_version(self):
        return self._route_version

    @route_version.setter
    def route_version(self, value):
        self._route_version = value
    @property
    def routes(self):
        return self._routes

    @routes.setter
    def routes(self, value):
        if isinstance(value, list):
            self._routes = list()
            for i in value:
                if isinstance(i, CloudbusRoute):
                    self._routes.append(i)
                else:
                    self._routes.append(CloudbusRoute.from_alipay_dict(i))
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.route_version:
            if hasattr(self.route_version, 'to_alipay_dict'):
                params['route_version'] = self.route_version.to_alipay_dict()
            else:
                params['route_version'] = self.route_version
        if self.routes:
            if isinstance(self.routes, list):
                for i in range(0, len(self.routes)):
                    element = self.routes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.routes[i] = element.to_alipay_dict()
            if hasattr(self.routes, 'to_alipay_dict'):
                params['routes'] = self.routes.to_alipay_dict()
            else:
                params['routes'] = self.routes
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataAiserviceCloudbusPredictbuslineSubmitModel()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'route_version' in d:
            o.route_version = d['route_version']
        if 'routes' in d:
            o.routes = d['routes']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.LabelFilter import LabelFilter


class LabelContext(object):

    def __init__(self):
        self._a = None

    @property
    def a(self):
        return self._a

    @a.setter
    def a(self, value):
        if isinstance(value, LabelFilter):
            self._a = value
        else:
            self._a = LabelFilter.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.a:
            if hasattr(self.a, 'to_alipay_dict'):
                params['a'] = self.a.to_alipay_dict()
            else:
                params['a'] = self.a
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LabelContext()
        if 'a' in d:
            o.a = d['a']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BoothContentInfoModel import BoothContentInfoModel
from alipay.aop.api.domain.OperationExtDataModel import OperationExtDataModel


class AlipayCommerceOperationContentQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceOperationContentQueryResponse, self).__init__()
        self._content_infos = None
        self._ext_data = None

    @property
    def content_infos(self):
        return self._content_infos

    @content_infos.setter
    def content_infos(self, value):
        if isinstance(value, list):
            self._content_infos = list()
            for i in value:
                if isinstance(i, BoothContentInfoModel):
                    self._content_infos.append(i)
                else:
                    self._content_infos.append(BoothContentInfoModel.from_alipay_dict(i))
    @property
    def ext_data(self):
        return self._ext_data

    @ext_data.setter
    def ext_data(self, value):
        if isinstance(value, OperationExtDataModel):
            self._ext_data = value
        else:
            self._ext_data = OperationExtDataModel.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceOperationContentQueryResponse, self).parse_response_content(response_content)
        if 'content_infos' in response:
            self.content_infos = response['content_infos']
        if 'ext_data' in response:
            self.ext_data = response['ext_data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CustomReportCondition import CustomReportCondition


class KoubeiMarketingDataCustomreportSaveModel(object):

    def __init__(self):
        self._report_condition_info = None

    @property
    def report_condition_info(self):
        return self._report_condition_info

    @report_condition_info.setter
    def report_condition_info(self, value):
        if isinstance(value, CustomReportCondition):
            self._report_condition_info = value
        else:
            self._report_condition_info = CustomReportCondition.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.report_condition_info:
            if hasattr(self.report_condition_info, 'to_alipay_dict'):
                params['report_condition_info'] = self.report_condition_info.to_alipay_dict()
            else:
                params['report_condition_info'] = self.report_condition_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingDataCustomreportSaveModel()
        if 'report_condition_info' in d:
            o.report_condition_info = d['report_condition_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AuthorizeInfo(object):

    def __init__(self):
        self._auth_ids = None
        self._auth_materials = None
        self._auth_name = None
        self._end_date = None
        self._start_date = None

    @property
    def auth_ids(self):
        return self._auth_ids

    @auth_ids.setter
    def auth_ids(self, value):
        if isinstance(value, list):
            self._auth_ids = list()
            for i in value:
                self._auth_ids.append(i)
    @property
    def auth_materials(self):
        return self._auth_materials

    @auth_materials.setter
    def auth_materials(self, value):
        if isinstance(value, list):
            self._auth_materials = list()
            for i in value:
                self._auth_materials.append(i)
    @property
    def auth_name(self):
        return self._auth_name

    @auth_name.setter
    def auth_name(self, value):
        self._auth_name = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_ids:
            if isinstance(self.auth_ids, list):
                for i in range(0, len(self.auth_ids)):
                    element = self.auth_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.auth_ids[i] = element.to_alipay_dict()
            if hasattr(self.auth_ids, 'to_alipay_dict'):
                params['auth_ids'] = self.auth_ids.to_alipay_dict()
            else:
                params['auth_ids'] = self.auth_ids
        if self.auth_materials:
            if isinstance(self.auth_materials, list):
                for i in range(0, len(self.auth_materials)):
                    element = self.auth_materials[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.auth_materials[i] = element.to_alipay_dict()
            if hasattr(self.auth_materials, 'to_alipay_dict'):
                params['auth_materials'] = self.auth_materials.to_alipay_dict()
            else:
                params['auth_materials'] = self.auth_materials
        if self.auth_name:
            if hasattr(self.auth_name, 'to_alipay_dict'):
                params['auth_name'] = self.auth_name.to_alipay_dict()
            else:
                params['auth_name'] = self.auth_name
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AuthorizeInfo()
        if 'auth_ids' in d:
            o.auth_ids = d['auth_ids']
        if 'auth_materials' in d:
            o.auth_materials = d['auth_materials']
        if 'auth_name' in d:
            o.auth_name = d['auth_name']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'start_date' in d:
            o.start_date = d['start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingCashticketTemplateCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCashticketTemplateCreateResponse, self).__init__()
        self._confirm_uri = None
        self._fund_order_no = None
        self._template_id = None

    @property
    def confirm_uri(self):
        return self._confirm_uri

    @confirm_uri.setter
    def confirm_uri(self, value):
        self._confirm_uri = value
    @property
    def fund_order_no(self):
        return self._fund_order_no

    @fund_order_no.setter
    def fund_order_no(self, value):
        self._fund_order_no = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCashticketTemplateCreateResponse, self).parse_response_content(response_content)
        if 'confirm_uri' in response:
            self.confirm_uri = response['confirm_uri']
        if 'fund_order_no' in response:
            self.fund_order_no = response['fund_order_no']
        if 'template_id' in response:
            self.template_id = response['template_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.Member import Member
from alipay.aop.api.domain.Member import Member


class MybankCreditSupplychainCreditpayTradeQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSupplychainCreditpayTradeQueryResponse, self).__init__()
        self._buyer = None
        self._buyer_scene_id = None
        self._confirm_amt = None
        self._create_date = None
        self._effect_date = None
        self._out_order_no = None
        self._refund_amt = None
        self._seller = None
        self._seller_scene_id = None
        self._source_order_no = None
        self._status = None
        self._trace_id = None
        self._trade_amt = None
        self._trade_no = None

    @property
    def buyer(self):
        return self._buyer

    @buyer.setter
    def buyer(self, value):
        if isinstance(value, Member):
            self._buyer = value
        else:
            self._buyer = Member.from_alipay_dict(value)
    @property
    def buyer_scene_id(self):
        return self._buyer_scene_id

    @buyer_scene_id.setter
    def buyer_scene_id(self, value):
        self._buyer_scene_id = value
    @property
    def confirm_amt(self):
        return self._confirm_amt

    @confirm_amt.setter
    def confirm_amt(self, value):
        self._confirm_amt = value
    @property
    def create_date(self):
        return self._create_date

    @create_date.setter
    def create_date(self, value):
        self._create_date = value
    @property
    def effect_date(self):
        return self._effect_date

    @effect_date.setter
    def effect_date(self, value):
        self._effect_date = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def refund_amt(self):
        return self._refund_amt

    @refund_amt.setter
    def refund_amt(self, value):
        self._refund_amt = value
    @property
    def seller(self):
        return self._seller

    @seller.setter
    def seller(self, value):
        if isinstance(value, Member):
            self._seller = value
        else:
            self._seller = Member.from_alipay_dict(value)
    @property
    def seller_scene_id(self):
        return self._seller_scene_id

    @seller_scene_id.setter
    def seller_scene_id(self, value):
        self._seller_scene_id = value
    @property
    def source_order_no(self):
        return self._source_order_no

    @source_order_no.setter
    def source_order_no(self, value):
        self._source_order_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value
    @property
    def trade_amt(self):
        return self._trade_amt

    @trade_amt.setter
    def trade_amt(self, value):
        self._trade_amt = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSupplychainCreditpayTradeQueryResponse, self).parse_response_content(response_content)
        if 'buyer' in response:
            self.buyer = response['buyer']
        if 'buyer_scene_id' in response:
            self.buyer_scene_id = response['buyer_scene_id']
        if 'confirm_amt' in response:
            self.confirm_amt = response['confirm_amt']
        if 'create_date' in response:
            self.create_date = response['create_date']
        if 'effect_date' in response:
            self.effect_date = response['effect_date']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'refund_amt' in response:
            self.refund_amt = response['refund_amt']
        if 'seller' in response:
            self.seller = response['seller']
        if 'seller_scene_id' in response:
            self.seller_scene_id = response['seller_scene_id']
        if 'source_order_no' in response:
            self.source_order_no = response['source_order_no']
        if 'status' in response:
            self.status = response['status']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']
        if 'trade_amt' in response:
            self.trade_amt = response['trade_amt']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchOrderDetailDataServiceItems(object):

    def __init__(self):
        self._area_codes = None
        self._carrier_code = None
        self._carrier_list = None
        self._category_attribute_value = None
        self._category_code = None
        self._category_ids = None
        self._channel_type = None
        self._desc = None
        self._img = None
        self._key_word = None
        self._key_word_list = None
        self._logo = None
        self._name = None
        self._parent_service_code = None
        self._region = None
        self._serv_search_catalogs = None
        self._serv_search_keywords = None
        self._service_code = None
        self._service_name = None
        self._service_time_end = None
        self._service_time_start = None
        self._short_desc = None
        self._spec_code = None
        self._template_id = None

    @property
    def area_codes(self):
        return self._area_codes

    @area_codes.setter
    def area_codes(self, value):
        self._area_codes = value
    @property
    def carrier_code(self):
        return self._carrier_code

    @carrier_code.setter
    def carrier_code(self, value):
        self._carrier_code = value
    @property
    def carrier_list(self):
        return self._carrier_list

    @carrier_list.setter
    def carrier_list(self, value):
        self._carrier_list = value
    @property
    def category_attribute_value(self):
        return self._category_attribute_value

    @category_attribute_value.setter
    def category_attribute_value(self, value):
        self._category_attribute_value = value
    @property
    def category_code(self):
        return self._category_code

    @category_code.setter
    def category_code(self, value):
        self._category_code = value
    @property
    def category_ids(self):
        return self._category_ids

    @category_ids.setter
    def category_ids(self, value):
        self._category_ids = value
    @property
    def channel_type(self):
        return self._channel_type

    @channel_type.setter
    def channel_type(self, value):
        self._channel_type = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def img(self):
        return self._img

    @img.setter
    def img(self, value):
        self._img = value
    @property
    def key_word(self):
        return self._key_word

    @key_word.setter
    def key_word(self, value):
        self._key_word = value
    @property
    def key_word_list(self):
        return self._key_word_list

    @key_word_list.setter
    def key_word_list(self, value):
        self._key_word_list = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def parent_service_code(self):
        return self._parent_service_code

    @parent_service_code.setter
    def parent_service_code(self, value):
        self._parent_service_code = value
    @property
    def region(self):
        return self._region

    @region.setter
    def region(self, value):
        self._region = value
    @property
    def serv_search_catalogs(self):
        return self._serv_search_catalogs

    @serv_search_catalogs.setter
    def serv_search_catalogs(self, value):
        self._serv_search_catalogs = value
    @property
    def serv_search_keywords(self):
        return self._serv_search_keywords

    @serv_search_keywords.setter
    def serv_search_keywords(self, value):
        self._serv_search_keywords = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value
    @property
    def service_time_end(self):
        return self._service_time_end

    @service_time_end.setter
    def service_time_end(self, value):
        self._service_time_end = value
    @property
    def service_time_start(self):
        return self._service_time_start

    @service_time_start.setter
    def service_time_start(self, value):
        self._service_time_start = value
    @property
    def short_desc(self):
        return self._short_desc

    @short_desc.setter
    def short_desc(self, value):
        self._short_desc = value
    @property
    def spec_code(self):
        return self._spec_code

    @spec_code.setter
    def spec_code(self, value):
        self._spec_code = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_codes:
            if hasattr(self.area_codes, 'to_alipay_dict'):
                params['area_codes'] = self.area_codes.to_alipay_dict()
            else:
                params['area_codes'] = self.area_codes
        if self.carrier_code:
            if hasattr(self.carrier_code, 'to_alipay_dict'):
                params['carrier_code'] = self.carrier_code.to_alipay_dict()
            else:
                params['carrier_code'] = self.carrier_code
        if self.carrier_list:
            if hasattr(self.carrier_list, 'to_alipay_dict'):
                params['carrier_list'] = self.carrier_list.to_alipay_dict()
            else:
                params['carrier_list'] = self.carrier_list
        if self.category_attribute_value:
            if hasattr(self.category_attribute_value, 'to_alipay_dict'):
                params['category_attribute_value'] = self.category_attribute_value.to_alipay_dict()
            else:
                params['category_attribute_value'] = self.category_attribute_value
        if self.category_code:
            if hasattr(self.category_code, 'to_alipay_dict'):
                params['category_code'] = self.category_code.to_alipay_dict()
            else:
                params['category_code'] = self.category_code
        if self.category_ids:
            if hasattr(self.category_ids, 'to_alipay_dict'):
                params['category_ids'] = self.category_ids.to_alipay_dict()
            else:
                params['category_ids'] = self.category_ids
        if self.channel_type:
            if hasattr(self.channel_type, 'to_alipay_dict'):
                params['channel_type'] = self.channel_type.to_alipay_dict()
            else:
                params['channel_type'] = self.channel_type
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.img:
            if hasattr(self.img, 'to_alipay_dict'):
                params['img'] = self.img.to_alipay_dict()
            else:
                params['img'] = self.img
        if self.key_word:
            if hasattr(self.key_word, 'to_alipay_dict'):
                params['key_word'] = self.key_word.to_alipay_dict()
            else:
                params['key_word'] = self.key_word
        if self.key_word_list:
            if hasattr(self.key_word_list, 'to_alipay_dict'):
                params['key_word_list'] = self.key_word_list.to_alipay_dict()
            else:
                params['key_word_list'] = self.key_word_list
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.parent_service_code:
            if hasattr(self.parent_service_code, 'to_alipay_dict'):
                params['parent_service_code'] = self.parent_service_code.to_alipay_dict()
            else:
                params['parent_service_code'] = self.parent_service_code
        if self.region:
            if hasattr(self.region, 'to_alipay_dict'):
                params['region'] = self.region.to_alipay_dict()
            else:
                params['region'] = self.region
        if self.serv_search_catalogs:
            if hasattr(self.serv_search_catalogs, 'to_alipay_dict'):
                params['serv_search_catalogs'] = self.serv_search_catalogs.to_alipay_dict()
            else:
                params['serv_search_catalogs'] = self.serv_search_catalogs
        if self.serv_search_keywords:
            if hasattr(self.serv_search_keywords, 'to_alipay_dict'):
                params['serv_search_keywords'] = self.serv_search_keywords.to_alipay_dict()
            else:
                params['serv_search_keywords'] = self.serv_search_keywords
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        if self.service_time_end:
            if hasattr(self.service_time_end, 'to_alipay_dict'):
                params['service_time_end'] = self.service_time_end.to_alipay_dict()
            else:
                params['service_time_end'] = self.service_time_end
        if self.service_time_start:
            if hasattr(self.service_time_start, 'to_alipay_dict'):
                params['service_time_start'] = self.service_time_start.to_alipay_dict()
            else:
                params['service_time_start'] = self.service_time_start
        if self.short_desc:
            if hasattr(self.short_desc, 'to_alipay_dict'):
                params['short_desc'] = self.short_desc.to_alipay_dict()
            else:
                params['short_desc'] = self.short_desc
        if self.spec_code:
            if hasattr(self.spec_code, 'to_alipay_dict'):
                params['spec_code'] = self.spec_code.to_alipay_dict()
            else:
                params['spec_code'] = self.spec_code
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchOrderDetailDataServiceItems()
        if 'area_codes' in d:
            o.area_codes = d['area_codes']
        if 'carrier_code' in d:
            o.carrier_code = d['carrier_code']
        if 'carrier_list' in d:
            o.carrier_list = d['carrier_list']
        if 'category_attribute_value' in d:
            o.category_attribute_value = d['category_attribute_value']
        if 'category_code' in d:
            o.category_code = d['category_code']
        if 'category_ids' in d:
            o.category_ids = d['category_ids']
        if 'channel_type' in d:
            o.channel_type = d['channel_type']
        if 'desc' in d:
            o.desc = d['desc']
        if 'img' in d:
            o.img = d['img']
        if 'key_word' in d:
            o.key_word = d['key_word']
        if 'key_word_list' in d:
            o.key_word_list = d['key_word_list']
        if 'logo' in d:
            o.logo = d['logo']
        if 'name' in d:
            o.name = d['name']
        if 'parent_service_code' in d:
            o.parent_service_code = d['parent_service_code']
        if 'region' in d:
            o.region = d['region']
        if 'serv_search_catalogs' in d:
            o.serv_search_catalogs = d['serv_search_catalogs']
        if 'serv_search_keywords' in d:
            o.serv_search_keywords = d['serv_search_keywords']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'service_name' in d:
            o.service_name = d['service_name']
        if 'service_time_end' in d:
            o.service_time_end = d['service_time_end']
        if 'service_time_start' in d:
            o.service_time_start = d['service_time_start']
        if 'short_desc' in d:
            o.short_desc = d['short_desc']
        if 'spec_code' in d:
            o.spec_code = d['spec_code']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniAmpeUsersceneQueryModel(object):

    def __init__(self):
        self._device_id = None
        self._product_id = None
        self._user_key = None

    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        self._product_id = value
    @property
    def user_key(self):
        return self._user_key

    @user_key.setter
    def user_key(self, value):
        self._user_key = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.product_id:
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        if self.user_key:
            if hasattr(self.user_key, 'to_alipay_dict'):
                params['user_key'] = self.user_key.to_alipay_dict()
            else:
                params['user_key'] = self.user_key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniAmpeUsersceneQueryModel()
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'product_id' in d:
            o.product_id = d['product_id']
        if 'user_key' in d:
            o.user_key = d['user_key']
        return o


